<?php
/* Smarty version 3.1.30, created on 2026-04-24 12:54:52
  from "/home/www/_rejestracja/template/partial/Shared/MenuTopChildTree.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.30',
  'unifunc' => 'content_69eb4bfc235cb3_05839242',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    '241faa534fef06e354b5e4bfe199f5a9a3d73820' => 
    array (
      0 => '/home/www/_rejestracja/template/partial/Shared/MenuTopChildTree.tpl',
      1 => 1490731078,
      2 => 'file',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_69eb4bfc235cb3_05839242 (Smarty_Internal_Template $_smarty_tpl) {
if (isset($_smarty_tpl->tpl_vars['arrayTree']->value[$_smarty_tpl->tpl_vars['active0']->value]) && $_smarty_tpl->tpl_vars['arrayTree']->value[$_smarty_tpl->tpl_vars['active0']->value]->GetHaveChildren()) {?>
<aside class="col-4 columnRight">

	<div class="menuRight">
			<?php $_smarty_tpl->_assignInScope('arrayTopArrayChild', $_smarty_tpl->tpl_vars['arrayTree']->value[$_smarty_tpl->tpl_vars['active0']->value]);
?> 
			<?php $_smarty_tpl->_assignInScope('countMenuChildArray', count($_smarty_tpl->tpl_vars['arrayTopArrayChild']->value));
?> 
			<?php if ($_smarty_tpl->tpl_vars['countMenuChildArray']->value > 0) {?>
				<?php $_smarty_tpl->_assignInScope('idChild', $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetId());
?>
				<?php $_smarty_tpl->_assignInScope('langChild', $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetLang());
?>
				<?php $_smarty_tpl->_assignInScope('urlChild', $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetUrlWithType());
?>
				<?php $_smarty_tpl->_assignInScope('urlNamChilde', $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetUrl());
?>
				<?php $_smarty_tpl->_assignInScope('nameChild', $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetMenuName());
?>
				<?php $_smarty_tpl->_assignInScope('subnameChild', $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetSubname());
?>
				<?php if ($_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->GetHaveChildren()) {?>
					<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['arrayTopArrayChild']->value->arrayChildren, 'objElementSubChild', false, 'keyChild');
$_smarty_tpl->tpl_vars['objElementSubChild']->index = -1;
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['keyChild']->value => $_smarty_tpl->tpl_vars['objElementSubChild']->value) {
$_smarty_tpl->tpl_vars['objElementSubChild']->index++;
$_smarty_tpl->tpl_vars['objElementSubChild']->first = !$_smarty_tpl->tpl_vars['objElementSubChild']->index;
$__foreach_objElementSubChild_2_saved = $_smarty_tpl->tpl_vars['objElementSubChild'];
?>
						<?php if (!$_smarty_tpl->tpl_vars['nameChild']->value) {?> 
							<?php $_smarty_tpl->_assignInScope('nameChild', $_smarty_tpl->tpl_vars['objElementSubChild']->value->GetName());
?>
						<?php }?>
						<?php $_smarty_tpl->_assignInScope('urlSubChild', $_smarty_tpl->tpl_vars['objElementSubChild']->value->GetUrlWithType());
?>
						<?php $_smarty_tpl->_assignInScope('idParentSubChild', $_smarty_tpl->tpl_vars['objElementSubChild']->value->GetId());
?>
						<?php if ($_smarty_tpl->tpl_vars['objElementSubChild']->first) {?>
							<div class="link1-head"><?php echo $_smarty_tpl->tpl_vars['nameChild']->value;?>
</div>
						<?php }?>
						<div class="link1"><a <?php if ($_smarty_tpl->tpl_vars['active1']->value == $_smarty_tpl->tpl_vars['objElementSubChild']->value->GetId()) {?>style="color: #68ceff;"<?php }?> href="<?php echo $_smarty_tpl->tpl_vars['urlSubChild']->value;?>
" ><?php echo $_smarty_tpl->tpl_vars['objElementSubChild']->value->GetElementName();?>
</a></div>
						<?php if ($_smarty_tpl->tpl_vars['objElementSubChild']->value->GetHaveChildren() && $_smarty_tpl->tpl_vars['active1']->value == $_smarty_tpl->tpl_vars['objElementSubChild']->value->getId()) {?> 
								<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['objElementSubChild']->value->arrayChildren, 'objElementSubSubChild', false, 'keyChild', 'childMenu', array (
));
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['keyChild']->value => $_smarty_tpl->tpl_vars['objElementSubSubChild']->value) {
?>
									<?php $_smarty_tpl->_assignInScope('urlSubSubChild', $_smarty_tpl->tpl_vars['objElementSubSubChild']->value->GetUrlWithType());
?>
									<?php $_smarty_tpl->_assignInScope('idParentSubSubChild', $_smarty_tpl->tpl_vars['objElementSubSubChild']->value->GetId());
?>
									<div class="link2"><a <?php if ($_smarty_tpl->tpl_vars['active2']->value == $_smarty_tpl->tpl_vars['objElementSubSubChild']->value->GetId()) {?>style="color: #68ceff;"<?php }?> href="<?php echo $_smarty_tpl->tpl_vars['urlSubSubChild']->value;?>
" ><?php echo $_smarty_tpl->tpl_vars['objElementSubSubChild']->value->GetElementName();?>
</a></div>
									<?php if ($_smarty_tpl->tpl_vars['objElementSubSubChild']->value->GetHaveChildren()) {?> 
										<?php $_smarty_tpl->_assignInScope('arraySubSubSub', $_smarty_tpl->tpl_vars['objElementSubSubChild']->value->arrayChildren);
?>
										<?php
$__section_keyElement_0_saved = isset($_smarty_tpl->tpl_vars['__smarty_section_keyElement']) ? $_smarty_tpl->tpl_vars['__smarty_section_keyElement'] : false;
$__section_keyElement_0_loop = (is_array(@$_loop=$_smarty_tpl->tpl_vars['arraySubSubSub']->value) ? count($_loop) : max(0, (int) $_loop));
$__section_keyElement_0_total = $__section_keyElement_0_loop;
$_smarty_tpl->tpl_vars['__smarty_section_keyElement'] = new Smarty_Variable(array());
if ($__section_keyElement_0_total != 0) {
for ($__section_keyElement_0_iteration = 1, $_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index'] = 0; $__section_keyElement_0_iteration <= $__section_keyElement_0_total; $__section_keyElement_0_iteration++, $_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index']++){
?>
											<div class="link3"><a <?php if ($_smarty_tpl->tpl_vars['active3']->value == $_smarty_tpl->tpl_vars['arraySubSubSub']->value[(isset($_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index']) ? $_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index'] : null)]->GetId()) {?>style="color: #68ceff;"<?php }?>  href="<?php echo $_smarty_tpl->tpl_vars['arraySubSubSub']->value[(isset($_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index']) ? $_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index'] : null)]->GetUrlWithType();?>
" ><?php echo $_smarty_tpl->tpl_vars['arraySubSubSub']->value[(isset($_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index']) ? $_smarty_tpl->tpl_vars['__smarty_section_keyElement']->value['index'] : null)]->GetElementName();?>
</a></div>

										<?php
}
}
if ($__section_keyElement_0_saved) {
$_smarty_tpl->tpl_vars['__smarty_section_keyElement'] = $__section_keyElement_0_saved;
}
?>
									<?php }?>			
								<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl);
?>

						<?php }?>			
					<?php
$_smarty_tpl->tpl_vars['objElementSubChild'] = $__foreach_objElementSubChild_2_saved;
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl);
?>

				<?php }?>	
			<?php }?>
		
	</div>
</aside>
<?php }
}
}
